Frequently Asked Questions — sphinx-notfound-page 0.4 documentation

# Frequently Asked Questions

## Does this extension work with Read the Docs?

Yes.

Read the Docs should detect the `404.html` page generated by the extension automatically, and serve it when a user hits a not found page.

If you are using a Single Version project, you may want to set `notfound_no_urls_prefix` to `True`.

## Does this extension work with GitHub pages?

Yes.

You may want to set `notfound_no_urls_prefix` to `True` and then add `permalink: /404.html` in the YAML front matter.

## The answer I’m looking for is not here

😢

Please, open an issue in our issue tracker and let us know what’s the problem you are having.

← Who Is Using It? notfound">`© Copyright 2019, Manuel Kaufmann.
A typlog sphinx theme, designed by Hsiaoming Yang.`